@@ -10,12 +10,12 @@ def check_file_paths(filepaths):
         filepaths: {[str]} -- image filepaths list
     
     Raises:
-        Exception: Need at least two .rawls image filepaths
         Exception: Invalid input filepaths extension
     """
 
-    if len(filepaths) < 2:
-        raise Exception('Need at least two rawls image filepaths as input')
-
-    if not all(['.rawls' in p for p in filepaths]):
-        raise Exception('Unvalid input filepath images, need .rawls image')
+    if isinstance(filepaths, list):
+        for p in filepaths:
+            check_file_paths(p)
+    else:
+        if not '.rawls' in filepaths:
+            raise Exception('Unvalid input filepath images, need .rawls image')
\ No newline at end of file
